==> advanced-spawn-async-0.0.0.tgz: package/lib/functions/core/index.js <==
"use strict";
const classes_1 = require("../../classes");
function callSpawn(spawn, command, args = [], options = {}) {
    const process = spawn(command, args, options);
    let stdout = '';
    let stderr = '';
    let output = '';
    process.stdout.on('data', chunk => {
        stdout += chunk;
        output += chunk;
    });
    process.stderr.on('data', chunk => {
        stderr += chunk;
        output += chunk;
    });
    const mkinfo = (status, signal) => ({
        command,
        args,
        options,
        stdout,
        stderr,
        output,
        status,
        signal,
        process
    });
    const createPromise = (event) => new Promise((resolve, reject) => {
        process.on('error', error => reject(new classes_1.InternalError({
            command,
            args,
            options,
            process,
            error
        })));
        process.on(event, (status, signal) => {
            const info = mkinfo(status, signal);
            if (status) {
                reject(new classes_1.TerminationError(info));
            }
            else {
                resolve(info);
            }
        });
    });
    const [onclose, onexit] = (() => {
        const { event } = options;
        if (event) {
            const promise = createPromise(event);
            return [promise, promise];
        }
        else {
            return [
                createPromise('close'),
                createPromise('exit')
            ];
        }
    })();
    return {
        onclose,
        onexit,
        process
    };
}
module.exports = callSpawn;

==> advanced-spawn-async-0.0.3.tgz: package/lib/functions/core/index.js <==
"use strict";
const classes_1 = require("../../classes");
function callSpawn(spawn, command, args = [], options = {}) {
    const process = spawn(command, args, options);
    let stdout = '';
    let stderr = '';
    let output = '';
    // NOTE: Use optional chaining when it is implemented in TypeScript
    process.stdout && process.stdout.on('data', chunk => {
        stdout += chunk;
        output += chunk;
    });
    // NOTE: Use optional chaining when it is implemented in TypeScript
    process.stderr && process.stderr.on('data', chunk => {
        stderr += chunk;
        output += chunk;
    });
    const mkinfo = (status, signal) => ({
        command,
        args,
        options,
        stdout,
        stderr,
        output,
        status,
        signal,
        process
    });
    const createPromise = (event) => new Promise((resolve, reject) => {
        process.on('error', error => reject(new classes_1.InternalError({
            command,
            args,
            options,
            process,
            error
        })));
        process.on(event, (status, signal) => {
            const info = mkinfo(status, signal);
            if (status) {
                reject(new classes_1.TerminationError(info));
            }
            else {
                resolve(info);
            }
        });
    });
    const [onclose, onexit] = (() => {
        const { event } = options;
        if (event) {
            const promise = createPromise(event);
            return [promise, promise];
        }
        else {
            return [
                createPromise('close'),
                createPromise('exit')
            ];
        }
    })();
    return {
        onclose,
        onexit,
        process
    };
}
module.exports = callSpawn;
